@@ -17,8 +17,6 @@ import (
 // With '--backrest.reference-count' flag.
 // The case when the backup is performed with block incremental feature flags.
 // Metric pgbackrest_backup_repo_size_bytes is set to 0.
-//
-//nolint:dupl
 func TestGetBackupMetrics(t *testing.T) {
 	type args struct {
 		stanzaName          string
@@ -44,7 +42,7 @@ pgbackrest_backup_error_status{backup_name="20210607-092423F",backup_type="full"
 # HELP pgbackrest_backup_info Backup info.
 # TYPE pgbackrest_backup_info gauge
 pgbackrest_backup_info{backrest_ver="2.45",backup_name="20210607-092423F",backup_type="full",block_incr="y",database_id="1",lsn_start="0/2000028",lsn_stop="0/2000100",pg_version="13",prior="",repo_key="1",stanza="demo",wal_start="000000010000000000000002",wal_stop="000000010000000000000002"} 1
-# HELP pgbackrest_backup_references Number of references to another backup (backup reference list).
+# HELP pgbackrest_backup_references Number of references to other backups (backup reference list).
 # TYPE pgbackrest_backup_references gauge
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="y",database_id="1",ref_backup="diff",repo_key="1",stanza="demo"} 0
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="y",database_id="1",ref_backup="full",repo_key="1",stanza="demo"} 0
@@ -163,8 +161,6 @@ pgbackrest_backup_size_bytes{backup_name="20210607-092423F",backup_type="full",b
 //   - pgbackrest_backup_repo_delta_map_bytes
 //
 // pgBackrest version < 2.44.
-//
-//nolint:dupl
 func TestGetRepoMapMetricsAbsent(t *testing.T) {
 	type args struct {
 		stanzaName          string
@@ -191,7 +187,7 @@ pgbackrest_backup_error_status{backup_name="20210607-092423F",backup_type="full"
 # HELP pgbackrest_backup_info Backup info.
 # TYPE pgbackrest_backup_info gauge
 pgbackrest_backup_info{backrest_ver="2.41",backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",lsn_start="0/2000028",lsn_stop="0/2000100",pg_version="13",prior="",repo_key="1",stanza="demo",wal_start="000000010000000000000002",wal_stop="000000010000000000000002"} 1
-# HELP pgbackrest_backup_references Number of references to another backup (backup reference list).
+# HELP pgbackrest_backup_references Number of references to other backups (backup reference list).
 # TYPE pgbackrest_backup_references gauge
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",ref_backup="diff",repo_key="1",stanza="demo"} 0
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",ref_backup="full",repo_key="1",stanza="demo"} 0
@@ -298,8 +294,6 @@ pgbackrest_backup_size_bytes{backup_name="20210607-092423F",backup_type="full",b
 //   - pgbackrest_backup_annotations
 //
 // pgBackrest version < 2.41.
-//
-//nolint:dupl
 func TestGetBackupMetricsDBsAbsent(t *testing.T) {
 	type args struct {
 		stanzaName          string
@@ -326,7 +320,7 @@ pgbackrest_backup_error_status{backup_name="20210607-092423F",backup_type="full"
 # HELP pgbackrest_backup_info Backup info.
 # TYPE pgbackrest_backup_info gauge
 pgbackrest_backup_info{backrest_ver="2.41",backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",lsn_start="0/2000028",lsn_stop="0/2000100",pg_version="13",prior="",repo_key="1",stanza="demo",wal_start="000000010000000000000002",wal_stop="000000010000000000000002"} 1
-# HELP pgbackrest_backup_references Number of references to another backup (backup reference list).
+# HELP pgbackrest_backup_references Number of references to other backups (backup reference list).
 # TYPE pgbackrest_backup_references gauge
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",ref_backup="diff",repo_key="1",stanza="demo"} 0
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",ref_backup="full",repo_key="1",stanza="demo"} 0
@@ -437,8 +431,6 @@ pgbackrest_backup_size_bytes{backup_name="20210607-092423F",backup_type="full",b
 //   - lsn_stop="-"
 //
 // pgBackrest version < 2.36.
-//
-//nolint:dupl
 func TestGetBackupMetricsErrorAbsent(t *testing.T) {
 	type args struct {
 		stanzaName          string
@@ -465,7 +457,7 @@ pgbackrest_backup_error_status{backup_name="20210607-092423F",backup_type="full"
 # HELP pgbackrest_backup_info Backup info.
 # TYPE pgbackrest_backup_info gauge
 pgbackrest_backup_info{backrest_ver="2.35",backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",lsn_start="-",lsn_stop="-",pg_version="13",prior="",repo_key="1",stanza="demo",wal_start="000000010000000000000002",wal_stop="000000010000000000000002"} 1
-# HELP pgbackrest_backup_references Number of references to another backup (backup reference list).
+# HELP pgbackrest_backup_references Number of references to other backups (backup reference list).
 # TYPE pgbackrest_backup_references gauge
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",ref_backup="diff",repo_key="1",stanza="demo"} 0
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",ref_backup="full",repo_key="1",stanza="demo"} 0
@@ -571,8 +563,6 @@ pgbackrest_backup_size_bytes{backup_name="20210607-092423F",backup_type="full",b
 //   - lsn_stop="-"
 //
 // pgBackrest version < v2.32
-//
-//nolint:dupl
 func TestGetBackupMetricsRepoAbsent(t *testing.T) {
 	type args struct {
 		stanzaName          string
@@ -599,7 +589,7 @@ pgbackrest_backup_error_status{backup_name="20210607-092423F",backup_type="full"
 # HELP pgbackrest_backup_info Backup info.
 # TYPE pgbackrest_backup_info gauge
 pgbackrest_backup_info{backrest_ver="2.31",backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",lsn_start="-",lsn_stop="-",pg_version="13",prior="",repo_key="0",stanza="demo",wal_start="000000010000000000000002",wal_stop="000000010000000000000002"} 1
-# HELP pgbackrest_backup_references Number of references to another backup (backup reference list).
+# HELP pgbackrest_backup_references Number of references to other backups (backup reference list).
 # TYPE pgbackrest_backup_references gauge
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",ref_backup="diff",repo_key="0",stanza="demo"} 0
 pgbackrest_backup_references{backup_name="20210607-092423F",backup_type="full",block_incr="n",database_id="1",ref_backup="full",repo_key="0",stanza="demo"} 0
