@@ -15,6 +15,7 @@ func TestGetExporterStatusMetrics(t *testing.T) {
 	type args struct {
 		stanzaName          string
 		getDataStatus       bool
+		excludeSpecified    bool
 		testText            string
 		setUpMetricValueFun setUpMetricValueFunType
 	}
@@ -26,6 +27,7 @@ func TestGetExporterStatusMetrics(t *testing.T) {
 			args{
 				"test",
 				true,
+				true,
 				`# HELP pgbackrest_exporter_status pgBackRest exporter get data status.
 # TYPE pgbackrest_exporter_status gauge
 pgbackrest_exporter_status{stanza="test"} 1
@@ -37,9 +39,34 @@ pgbackrest_exporter_status{stanza="test"} 1
 			args{
 				"test",
 				false,
+				false,
 				`# HELP pgbackrest_exporter_status pgBackRest exporter get data status.
 # TYPE pgbackrest_exporter_status gauge
 pgbackrest_exporter_status{stanza="test"} 0
+`,
+				setUpMetricValue,
+			},
+		},
+		{"GetExporterStatusAllStanzasExceptExcluded",
+			args{
+				"",
+				true,
+				true,
+				`# HELP pgbackrest_exporter_status pgBackRest exporter get data status.
+# TYPE pgbackrest_exporter_status gauge
+pgbackrest_exporter_status{stanza="all-stanzas-except-excluded"} 1
+`,
+				setUpMetricValue,
+			},
+		},
+		{"GetExporterStatusAllStanzas",
+			args{
+				"",
+				true,
+				false,
+				`# HELP pgbackrest_exporter_status pgBackRest exporter get data status.
+# TYPE pgbackrest_exporter_status gauge
+pgbackrest_exporter_status{stanza="all-stanzas"} 1
 `,
 				setUpMetricValue,
 			},
@@ -48,7 +75,7 @@ pgbackrest_exporter_status{stanza="test"} 0
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			resetExporterMetrics()
-			getExporterStatusMetrics(tt.args.stanzaName, tt.args.getDataStatus, tt.args.setUpMetricValueFun, logger)
+			getExporterStatusMetrics(tt.args.stanzaName, tt.args.getDataStatus, tt.args.excludeSpecified, tt.args.setUpMetricValueFun, logger)
 			reg := prometheus.NewRegistry()
 			reg.MustRegister(pgbrExporterStatusMetric)
 			metricFamily, err := reg.Gather()
@@ -72,6 +99,7 @@ func TestGetExporterStatusErrorsAndDebugs(t *testing.T) {
 	type args struct {
 		stanzaName          string
 		getDataStatus       bool
+		excludeSpecified    bool
 		setUpMetricValueFun setUpMetricValueFunType
 		errorsCount         int
 		debugsCount         int
@@ -84,6 +112,7 @@ func TestGetExporterStatusErrorsAndDebugs(t *testing.T) {
 			args{
 				`test`,
 				true,
+				false,
 				fakeSetUpMetricValue,
 				1,
 				1,
@@ -94,7 +123,7 @@ func TestGetExporterStatusErrorsAndDebugs(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			out := &bytes.Buffer{}
 			lc := slog.New(slog.NewTextHandler(out, &slog.HandlerOptions{Level: slog.LevelDebug}))
-			getExporterStatusMetrics(tt.args.stanzaName, tt.args.getDataStatus, tt.args.setUpMetricValueFun, lc)
+			getExporterStatusMetrics(tt.args.stanzaName, tt.args.getDataStatus, tt.args.excludeSpecified, tt.args.setUpMetricValueFun, lc)
 			errorsOutputCount := strings.Count(out.String(), "level=ERROR")
 			debugsOutputCount := strings.Count(out.String(), "level=DEBUG")
 			if tt.args.errorsCount != errorsOutputCount || tt.args.debugsCount != debugsOutputCount {
