@@ -196,6 +196,24 @@ func TestReturnBackupSetExecArgs(t *testing.T) {
 	}
 }
 
+func TestReturnVersionExecArgs(t *testing.T) {
+	tests := []struct {
+		name string
+		want []string
+	}{
+		{"returnVersionExecArgs",
+			[]string{"version", "--output", "num"},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			if got := returnVersionExecArgs(); !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("\nVariables do not match:\n%s\nwant:\n%s", got, tt.want)
+			}
+		})
+	}
+}
+
 func TestConcatExecArgs(t *testing.T) {
 	type args struct {
 		slices [][]string
@@ -410,7 +428,7 @@ func TestCompareLastBackups(t *testing.T) {
 	}
 }
 
-func TestStanzaNotInExclude(t *testing.T) {
+func TestStanzaInExclude(t *testing.T) {
 	type args struct {
 		stanza      string
 		listExclude []string
@@ -420,22 +438,22 @@ func TestStanzaNotInExclude(t *testing.T) {
 		args args
 		want bool
 	}{
-		{"stanzaNotInExcludeEmptyListExclude",
+		{"stanzaInExcludeEmptyListExclude",
 			args{"", []string{""}},
-			true},
-		{"stanzaNotInExcludeEmptyListExcludeNotEmptyStanza",
-			args{"demo", []string{""}},
-			true},
-		{"stanzaNotInExcludeStanzaNotInExcludeList",
-			args{"demo", []string{"demo-test", "test"}},
-			true},
-		{"stanzaNotInExcludeStanzaInExcludeList",
-			args{"demo", []string{"demo", "test"}},
 			false},
+		{"stanzaInExcludeEmptyListExcludeNotEmptyStanza",
+			args{"demo", []string{""}},
+			false},
+		{"stanzaInExcludeStanzaNotInExcludeList",
+			args{"demo", []string{"demo-test", "test"}},
+			false},
+		{"stanzaInExcludeStanzaInExcludeList",
+			args{"demo", []string{"demo", "test"}},
+			true},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			if got := stanzaNotInExclude(tt.args.stanza, tt.args.listExclude); got != tt.want {
+			if got := stanzaInExclude(tt.args.stanza, tt.args.listExclude); got != tt.want {
 				t.Errorf("\nVariables do not match:\n%v\nwant:\n%v", got, tt.want)
 			}
 		})
@@ -446,7 +464,6 @@ func fakeSetUpMetricValue(metric *prometheus.GaugeVec, value float64, labels ...
 	return errors.New("сustorm error for test")
 }
 
-//nolint:unparam
 func templateStanza(walMax, walMin string, dbRef []databaseRef, errorStatus, stanzaLock bool, deltaMap, sizeMap, stanzaSizeTotal, stanzaSizeComplete int64, backupAnnotation annotation) stanza {
 	var (
 		size *int64
@@ -538,7 +555,6 @@ func templateStanza(walMax, walMin string, dbRef []databaseRef, errorStatus, sta
 	}
 }
 
-//nolint:unparam
 func templateStanzaRepoMapSizesAbsent(walMax, walMin string, dbRef []databaseRef, errorStatus bool, size int64, backupAnnotation annotation) stanza {
 	var (
 		deltaMap, sizeMap, stanzaSizeTotal, stanzaSizeComplete *int64
@@ -630,7 +646,6 @@ func templateStanzaRepoMapSizesAbsent(walMax, walMin string, dbRef []databaseRef
 	}
 }
 
-//nolint:unparam
 func templateStanzaDBsAbsent(walMax, walMin string, dbRef []databaseRef, errorStatus bool, size int64) stanza {
 	var (
 		deltaMap, sizeMap, stanzaSizeTotal, stanzaSizeComplete *int64
@@ -723,7 +738,6 @@ func templateStanzaDBsAbsent(walMax, walMin string, dbRef []databaseRef, errorSt
 	}
 }
 
-//nolint:unparam
 func templateStanzaErrorAbsent(walMax, walMin string, size int64) stanza {
 	var (
 		errorStatus                                            *bool
@@ -817,7 +831,6 @@ func templateStanzaErrorAbsent(walMax, walMin string, size int64) stanza {
 	}
 }
 
-//nolint:unparam
 func templateStanzaRepoAbsent(walMax, walMin string, size int64) stanza {
 	var (
 		errorStatus                                            *bool
@@ -984,6 +997,103 @@ func TestGetParsedSpecificBackupInfoDataErrors(t *testing.T) {
 	}
 }
 
+func TestGetVersionData(t *testing.T) {
+	type args struct {
+		mockStdout string
+		mockStderr string
+		mockExit   int
+	}
+	tests := []struct {
+		name    string
+		args    args
+		want    []byte
+		wantErr bool
+	}{
+		{
+			"getVersionDataSuccess",
+			args{
+				"2057000",
+				"",
+				0,
+			},
+			[]byte("2057000"),
+			false,
+		},
+		{
+			"getVersionDataError",
+			args{
+				"",
+				"pgbackrest: command not found",
+				127,
+			},
+			nil,
+			true,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			mockData = mockStruct{tt.args.mockStdout, tt.args.mockStderr, tt.args.mockExit}
+			execCommand = fakeExecCommand
+			defer func() { execCommand = exec.Command }()
+			out := &bytes.Buffer{}
+			lc := slog.New(slog.NewTextHandler(out, &slog.HandlerOptions{Level: slog.LevelDebug}))
+			got, err := getVersionData(lc)
+			if (err != nil) != tt.wantErr {
+				t.Errorf("\ngetVersionData() error = %v, wantErr %v", err, tt.wantErr)
+				return
+			}
+			if !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("\nVariables do not match:\n%v\nwant:\n%v", got, tt.want)
+			}
+		})
+	}
+}
+
+func TestParseVersionOutput(t *testing.T) {
+	type args struct {
+		output []byte
+	}
+	tests := []struct {
+		name    string
+		args    args
+		want    float64
+		wantErr bool
+	}{
+		{
+			"parseVersionOutputSuccess",
+			args{[]byte("2057000")},
+			2057000,
+			false,
+		},
+		{
+			"parseVersionOutputInvalidFormat",
+			args{[]byte("pgBackRest 2.40")},
+			0,
+			true,
+		},
+		{
+			"parseVersionOutputEmptyString",
+			args{[]byte("")},
+			0,
+			true,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			out := &bytes.Buffer{}
+			lc := slog.New(slog.NewTextHandler(out, &slog.HandlerOptions{Level: slog.LevelDebug}))
+			got, err := parseVersionOutput(tt.args.output, lc)
+			if (err != nil) != tt.wantErr {
+				t.Errorf("\nparseVersionOutput() error = %v, wantErr %v", err, tt.wantErr)
+				return
+			}
+			if got != tt.want {
+				t.Errorf("\nVariables do not match:\n%v\nwant:\n%v", got, tt.want)
+			}
+		})
+	}
+}
+
 func fakeExecCommandSpecificDatabase(command string, args ...string) *exec.Cmd {
 	var (
 		stdOut, stdErr string
@@ -1026,7 +1136,6 @@ func checkBackupType(a []string, regex string) bool {
 	return false
 }
 
-//nolint:unparam
 func templateLastBackup() lastBackupsStruct {
 	return lastBackupsStruct{
 		backupStruct{"20210607-092423F", "full", time.Unix(1623057866, 0), 3, 24316343, 24316343, 2969514, valToPtr(int64(12)), nil, valToPtr(int64(100)), valToPtr(true), valToPtr(annotation{"testkey": "testvalue"}), "y", []string{""}},
@@ -1059,7 +1168,6 @@ func templateLastBackupErrorAbsent() lastBackupsStruct {
 	}
 }
 
-//nolint:unparam
 func templateLastBackupDifferent() lastBackupsStruct {
 	return lastBackupsStruct{
 		backupStruct{"20220926-201857F", "full", time.Unix(1623706322, 0), 3, 24316343, 24316343, 2969514, valToPtr(int64(12)), nil, valToPtr(int64(100)), valToPtr(false), valToPtr(annotation{"testkey": "testvalue"}), "y", []string{""}},
@@ -1069,8 +1177,6 @@ func templateLastBackupDifferent() lastBackupsStruct {
 }
 
 // Implement custom comparators for testing.
-//
-//nolint:gocyclo
 func compareBackupStructs(a, b backupStruct) bool {
 	if a.backupLabel != b.backupLabel {
 		return false
